@@ -21,23 +21,26 @@ scoringFunction <- function(max_depth, min_child_weight, subsample) {
 
   dtrain <- xgb.DMatrix(agaricus.train$data,label = agaricus.train$label)
   
-  Pars <- list( booster = "gbtree"
-              , eta = 0.01
-              , max_depth = max_depth
-              , min_child_weight = min_child_weight
-              , subsample = subsample
-              , objective = "binary:logistic"
-              , eval_metric = "auc")
+  Pars <- list( 
+      booster = "gbtree"
+    , eta = 0.01
+    , max_depth = max_depth
+    , min_child_weight = min_child_weight
+    , subsample = subsample
+    , objective = "binary:logistic"
+    , eval_metric = "auc"
+  )
 
-  xgbcv <- xgb.cv(params = Pars
-                , data = dtrain
-                , nround = 100
-                , folds = Folds
-                , prediction = TRUE
-                , showsd = TRUE
-                , early_stopping_rounds = 5
-                , maximize = TRUE
-                , verbose = 0)
+  xgbcv <- xgb.cv(
+      params = Pars
+    , data = dtrain
+    , nround = 100
+    , folds = Folds
+    , prediction = TRUE
+    , showsd = TRUE
+    , early_stopping_rounds = 5
+    , maximize = TRUE
+            , verbose = 0)
 
   return(list( Score = max(xgbcv$evaluation_log$test_auc_mean)
              , nrounds = xgbcv$best_iteration
@@ -46,25 +49,20 @@ scoringFunction <- function(max_depth, min_child_weight, subsample) {
 }
 
 ## ----eval = TRUE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-bounds <- list( max_depth = c(2L, 10L)
-              , min_child_weight = c(1, 100)
-              , subsample = c(0.25, 1))
-
-kern <- "Matern52"
-
-acq <- "ei"
+bounds <- list( 
+    max_depth = c(2L, 10L)
+  , min_child_weight = c(1, 25)
+  , subsample = c(0.25, 1)
+)
 
 ## ----eval = TRUE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-ScoreResult <- BayesianOptimization(FUN = scoringFunction
-                                  , bounds = bounds
-                                  , initPoints = 10
-                                  , bulkNew = 1
-                                  , nIters = 12
-                                  , kern = kern
-                                  , acq = acq
-                                  , kappa = 2.576
-                                  , verbose = 1
-                                  , parallel = FALSE)
+set.seed(1234)
+ScoreResult <- BayesianOptimization(
+    FUN = scoringFunction
+  , bounds = bounds
+  , initPoints = 4
+  , nIters = 6
+)
 
 ## ----eval = TRUE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 ScoreResult$ScoreDT
